@@ -28,10 +28,10 @@ Example:
     >>> config = AgentConfig.load("./my_agent")
     >>> config.launch_type = "hybrid"
     >>> config.save()
-    >>> 
+    >>>
     >>> # Fluent API
     >>> config.set_launch_type("hybrid").set_model("deepseek-v3").save()
-    >>> 
+    >>>
     >>> # Use with Client
     >>> client = AgentKitClient(config)
 """
@@ -40,6 +40,9 @@ from typing import Optional, Dict, Any, Union
 from pathlib import Path
 import logging
 
+from ..config import AgentkitConfigManager, CommonConfig, get_config
+from ..config.config_validator import ConfigValidator
+
 logger = logging.getLogger(__name__)
 
 
@@ -87,83 +90,129 @@ class AgentConfig:
         >>> region = config.get("launch_types.cloud.region")
         >>> config.set("launch_types.hybrid.image_tag", "v1.0.0")
     """
-    
+
     def __init__(self, file_path: Union[str, Path]):
         """Initialize AgentConfig.
-        
+
         Args:
             file_path: Path to agentkit.yaml or project directory.
                       If a directory is provided, will look for agentkit.yaml inside.
-        
+
         Raises:
             FileNotFoundError: If the configuration file doesn't exist.
-        
+
         Example:
             >>> config = AgentConfig("./my_agent")  # directory
             >>> config = AgentConfig("./my_agent/agentkit.yaml")  # file
         """
         self.file_path = Path(file_path)
-        
+
         # If directory provided, append agentkit.yaml
         if self.file_path.is_dir():
             self.file_path = self.file_path / "agentkit.yaml"
-        
+
         if not self.file_path.exists():
             raise FileNotFoundError(
                 f"Configuration file not found: {self.file_path}\n"
                 f"Please ensure the file exists or use AgentKitClient.init_project() "
                 f"to create a new project."
             )
-        
+
         # Load configuration using the existing config manager
-        from ..config import get_config
         self._manager = get_config(config_path=str(self.file_path))
-        
+
         # Cache common config for quick access
         self._common_config = self._manager.get_common_config()
-    
+
     @classmethod
-    def load(cls, path: Union[str, Path]) -> 'AgentConfig':
+    def create(
+        cls,
+        project_dir: Union[str, Path],
+        *,
+        agent_name: str,
+        entry_point: str,
+        language: str = "Python",
+        launch_type: str = "cloud",
+        description: Optional[str] = None,
+        dependencies_file: Optional[str] = None,
+    ) -> "AgentConfig":
+        config_path = Path(project_dir)
+
+        if config_path.is_dir():
+            config_path = config_path / "agentkit.yaml"
+
+        if config_path.exists():
+            raise FileExistsError(f"Configuration file already exists: {config_path}")
+
+        manager = AgentkitConfigManager(config_path=config_path)
+        common_config: CommonConfig = manager.get_common_config()
+
+        common_config.agent_name = agent_name
+        common_config.entry_point = entry_point
+
+        if description is not None:
+            common_config.description = description
+
+        if language:
+            common_config.set_language(language)
+
+        if dependencies_file is not None:
+            common_config.dependencies_file = dependencies_file
+
+        common_config.launch_type = launch_type
+
+        validator = ConfigValidator()
+        errors = validator.validate_common_config(common_config)
+        if errors:
+            joined = "; ".join(errors)
+            raise ValueError(f"Invalid agent configuration: {joined}")
+
+        manager.update_common_config(common_config)
+
+        return cls(config_path)
+
+    @classmethod
+    def load(cls, path: Union[str, Path]) -> "AgentConfig":
         """Load configuration from file or directory.
-        
+
         This is the recommended way to create an AgentConfig instance.
-        
+
         Args:
             path: Path to agentkit.yaml or project directory containing it.
-        
+
         Returns:
             AgentConfig instance
-        
+
         Raises:
             FileNotFoundError: If the configuration file doesn't exist.
-        
+
         Example:
             >>> # Load from directory
             >>> config = AgentConfig.load("./my_agent")
-            >>> 
+            >>>
             >>> # Load from file
             >>> config = AgentConfig.load("./my_agent/agentkit.yaml")
         """
         return cls(path)
-    
+
     # ========== Type-safe Property Accessors ==========
-    
+
     @property
     def launch_type(self) -> str:
         """Get or set launch type (deployment mode).
-        
+
         Valid values: 'local', 'cloud', 'hybrid'
-        
+
         Example:
             >>> config.launch_type = "hybrid"
             >>> print(config.launch_type)  # "hybrid"
         """
         return self._common_config.launch_type
-    
+
     @launch_type.setter
     def launch_type(self, value: str):
         """Set launch type with validation."""
-        valid_types = ['local', 'cloud', 'hybrid']
+        valid_types = ["local", "cloud", "hybrid"]
         if value not in valid_types:
             raise ValueError(
                 f"Invalid launch_type: '{value}'. "
@@ -171,111 +220,111 @@ class AgentConfig:
             )
         self._common_config.launch_type = value
         logger.debug(f"Set launch_type to '{value}'")
-    
+
     @property
     def agent_name(self) -> str:
         """Get or set agent name.
-        
+
         Example:
             >>> config.agent_name = "my_planning_agent"
         """
         return self._common_config.agent_name
-    
+
     @agent_name.setter
     def agent_name(self, value: str):
         """Set agent name."""
         self._common_config.agent_name = value
         logger.debug(f"Set agent_name to '{value}'")
-    
+
     @property
     def entry_point(self) -> str:
         """Get or set entry point file.
-        
+
         Example:
             >>> config.entry_point = "agent.py"
         """
         return self._common_config.entry_point
-    
+
     @entry_point.setter
     def entry_point(self, value: str):
         """Set entry point."""
         self._common_config.entry_point = value
         logger.debug(f"Set entry_point to '{value}'")
-    
+
     @property
     def description(self) -> str:
         """Get or set agent description.
-        
+
         Example:
             >>> config.description = "A planning agent for task decomposition"
         """
         return self._common_config.description
-    
+
     @description.setter
     def description(self, value: str):
         """Set description."""
         self._common_config.description = value
         logger.debug(f"Set description to '{value}'")
-    
+
     @property
     def language(self) -> str:
         """Get or set programming language.
-        
+
         Valid values: 'Python', 'Golang'
-        
+
         Example:
             >>> config.language = "Python"
         """
         return self._common_config.language
-    
+
     @language.setter
     def language(self, value: str):
         """Set language."""
         self._common_config.language = value
         logger.debug(f"Set language to '{value}'")
-    
+
     @property
     def language_version(self) -> str:
         """Get or set language version.
-        
+
         Example:
             >>> config.language_version = "3.12"
         """
         return self._common_config.language_version
-    
+
     @language_version.setter
     def language_version(self, value: str):
         """Set language version."""
         self._common_config.language_version = value
         logger.debug(f"Set language_version to '{value}'")
-    
+
     @property
     def dependencies_file(self) -> str:
         """Get or set dependencies file path.
-        
+
         Example:
             >>> config.dependencies_file = "requirements.txt"
         """
         return self._common_config.dependencies_file
-    
+
     @dependencies_file.setter
     def dependencies_file(self, value: str):
         """Set dependencies file."""
         self._common_config.dependencies_file = value
         logger.debug(f"Set dependencies_file to '{value}'")
-    
+
     @property
     def runtime_envs(self) -> Dict[str, str]:
         """Get or set application-level runtime environment variables.
-        
+
         These environment variables are shared across all deployment modes.
-        
+
         Example:
             >>> config.runtime_envs = {"KEY1": "VALUE1", "KEY2": "VALUE2"}
             >>> config.runtime_envs["NEW_VAR"] = "VALUE3"
         """
         return self._common_config.runtime_envs
-    
+
     @runtime_envs.setter
     def runtime_envs(self, value: Dict[str, str]):
         """Set runtime environment variables."""
@@ -283,22 +332,22 @@ class AgentConfig:
             raise TypeError("runtime_envs must be a dictionary")
         self._common_config.runtime_envs = value
         logger.debug(f"Set runtime_envs with {len(value)} entries")
-    
+
     # ========== Path-based Access Methods ==========
-    
+
     def get(self, key_path: str, default: Any = None) -> Any:
         """Get configuration value by key path.
-        
+
         Supports dot-notation for nested access.
-        
+
         Args:
             key_path: Dot-separated key path (e.g., "common.launch_type" or
                      "launch_types.cloud.region")
             default: Default value if key not found
-        
+
         Returns:
             Configuration value or default
-        
+
         Example:
             >>> config.get("common.launch_type")
             'cloud'
@@ -308,8 +357,8 @@ class AgentConfig:
             'default'
         """
         return self._manager.get_raw_value(key_path, default=default)
-    
-    def set(self, key_path: str, value: Any) -> 'AgentConfig':
+
+    def set(self, key_path: str, value: Any) -> "AgentConfig":
         """Set configuration value by key path.
         
         Supports dot-notation for nested access. Returns self for chaining.
@@ -332,35 +381,35 @@ class AgentConfig:
         """
         # Update internal data structure
         self._manager.set_raw_value(key_path, value)
-        
+
         # If updating common config, reload cache
         if key_path.startswith("common."):
             self._common_config = self._manager.get_common_config()
-        
+
         logger.debug(f"Set '{key_path}' to '{value}'")
         return self
-    
-    def update(self, updates: Dict[str, Any]) -> 'AgentConfig':
+
+    def update(self, updates: Dict[str, Any]) -> "AgentConfig":
         """Batch update configuration.
-        
+
         Updates multiple configuration values at once. Supports both flat keys
         (for common config fields) and nested dictionaries.
-        
+
         Args:
             updates: Dictionary of updates. Can contain:
                     - Flat keys like "launch_type" (updates common config)
                     - Nested dicts like {"common": {"launch_type": "hybrid"}}
-        
+
         Returns:
             Self for method chaining
-        
+
         Example:
             >>> # Update common config fields
             >>> config.update({
             ...     "launch_type": "hybrid",
             ...     "description": "New description"
             ... })
-            >>> 
+            >>>
             >>> # Update nested config
             >>> config.update({
             ...     "common": {
@@ -372,7 +421,7 @@ class AgentConfig:
             ...         }
             ...     }
             ... })
-            >>> 
+            >>>
             >>> # Chaining
             >>> config.update({"launch_type": "hybrid"}).save()
         """
@@ -389,48 +438,48 @@ class AgentConfig:
             else:
                 # Treat as path
                 self.set(key, value)
-        
+
         logger.debug(f"Updated {len(updates)} configuration entries")
         return self
-    
+
     # ========== Fluent API Methods (Chainable) ==========
-    
-    def set_launch_type(self, launch_type: str) -> 'AgentConfig':
+
+    def set_launch_type(self, launch_type: str) -> "AgentConfig":
         """Set launch type (fluent API).
-        
+
         Args:
             launch_type: 'local', 'cloud', or 'hybrid'
-        
+
         Returns:
             Self for method chaining
-        
+
         Example:
             >>> config.set_launch_type("hybrid").save()
         """
         self.launch_type = launch_type
         return self
-    
-    def set_agent_name(self, agent_name: str) -> 'AgentConfig':
+
+    def set_agent_name(self, agent_name: str) -> "AgentConfig":
         """Set agent name (fluent API)."""
         self.agent_name = agent_name
         return self
-    
-    def set_description(self, description: str) -> 'AgentConfig':
+
+    def set_description(self, description: str) -> "AgentConfig":
         """Set description (fluent API)."""
         self.description = description
         return self
-    
-    def set_entry_point(self, entry_point: str) -> 'AgentConfig':
+
+    def set_entry_point(self, entry_point: str) -> "AgentConfig":
         """Set entry point (fluent API)."""
         self.entry_point = entry_point
         return self
-    
-    def set_language(self, language: str) -> 'AgentConfig':
+
+    def set_language(self, language: str) -> "AgentConfig":
         """Set language (fluent API)."""
         self.language = language
         return self
-    
-    def add_runtime_env(self, key: str, value: str) -> 'AgentConfig':
+
+    def add_runtime_env(self, key: str, value: str) -> "AgentConfig":
         """Add a runtime environment variable (fluent API).
         
         Args:
@@ -448,44 +497,50 @@ class AgentConfig:
         self._common_config.runtime_envs[key] = value
         logger.debug(f"Added runtime_env: {key}={value}")
         return self
-    
+
     # ========== Persistence Methods ==========
-    
-    def save(self, path: Optional[Union[str, Path]] = None) -> 'AgentConfig':
+
+    def save(self, path: Optional[Union[str, Path]] = None) -> "AgentConfig":
         """Save configuration to file.
-        
+
         Args:
             path: Optional new path to save to. If None, saves to original file.
-        
+
         Returns:
             Self for method chaining
-        
+
         Example:
             >>> config.launch_type = "hybrid"
             >>> config.save()  # Save to original file
-            >>> 
+            >>>
             >>> config.save("new_config.yaml")  # Save to new file
         """
+        validator = ConfigValidator()
+        errors = validator.validate_common_config(self._common_config)
+        if errors:
+            joined = "; ".join(errors)
+            raise ValueError(f"Invalid agent configuration: {joined}")
+
         # Update common config in manager
         self._manager.update_common_config(self._common_config)
-        
+
         # If new path specified, update file path
         if path:
             self.file_path = Path(path)
             # Note: The manager still uses the original path for saving
             # This is intentional to maintain consistency
-        
+
         logger.info(f"Configuration saved to {self.file_path}")
         return self
-    
-    def reload(self) -> 'AgentConfig':
+
+    def reload(self) -> "AgentConfig":
         """Reload configuration from file.
-        
+
         Discards any unsaved changes and reloads from disk.
-        
+
         Returns:
             Self for method chaining
-        
+
         Example:
             >>> config.reload()  # Discard changes
         """
@@ -493,16 +548,16 @@ class AgentConfig:
         self._common_config = self._manager.get_common_config()
         logger.info(f"Configuration reloaded from {self.file_path}")
         return self
-    
+
     # ========== Export Methods ==========
-    
+
     def to_dict(self) -> Dict[str, Any]:
         """Export configuration as dictionary.
-        
+
         Returns:
             Complete configuration dictionary including common config
-            and all workflow configurations.
-        
+            and all strategy configurations.
+
         Example:
             >>> config_dict = config.to_dict()
             >>> print(config_dict.keys())
@@ -511,61 +566,61 @@ class AgentConfig:
         return {
             "common": self._common_config.to_dict(),
             "launch_types": {
-                name: self._manager.get_workflow_config(name)
-                for name in self._manager.list_workflows()
-            }
+                name: self._manager.get_strategy_config(name)
+                for name in self._manager.list_strategies()
+            },
         }
-    
-    def get_workflow_config(self, workflow_name: Optional[str] = None) -> Dict[str, Any]:
-        """Get workflow-specific configuration.
-        
+
+    def get_strategy_config(
+        self, strategy_name: Optional[str] = None
+    ) -> Dict[str, Any]:
+        """Get strategy-specific configuration.
+
         Args:
-            workflow_name: Workflow name ('local', 'cloud', 'hybrid').
+            strategy_name: strategy name ('local', 'cloud', 'hybrid').
                           If None, uses current launch_type.
-        
+
         Returns:
-            Workflow configuration dictionary
-        
+            strategy configuration dictionary
+
         Example:
-            >>> cloud_config = config.get_workflow_config("cloud")
+            >>> cloud_config = config.get_strategy_config("cloud")
             >>> print(cloud_config.get("region"))
             'cn-beijing'
-            >>> 
-            >>> # Get current workflow config
-            >>> current_config = config.get_workflow_config()
+            >>>
+            >>> # Get current strategy config
+            >>> current_config = config.get_strategy_config()
         """
-        if workflow_name is None:
-            workflow_name = self.launch_type
-        return self._manager.get_workflow_config(workflow_name)
-    
-    def update_workflow_config(
-        self,
-        config: Dict[str, Any],
-        workflow_name: Optional[str] = None
-    ) -> 'AgentConfig':
-        """Update workflow-specific configuration.
-        
+        if strategy_name is None:
+            strategy_name = self.launch_type
+        return self._manager.get_strategy_config(strategy_name)
+
+    def update_strategy_config(
+        self, config: Dict[str, Any], strategy_name: Optional[str] = None
+    ) -> "AgentConfig":
+        """Update strategy-specific configuration.
+
         Args:
-            config: Workflow configuration updates
-            workflow_name: Workflow name. If None, uses current launch_type.
-        
+            config: strategy configuration updates
+            strategy_name: strategy name. If None, uses current launch_type.
+
         Returns:
             Self for method chaining
-        
+
         Example:
-            >>> config.update_workflow_config({
+            >>> config.update_strategy_config({
             ...     "region": "cn-beijing",
             ...     "image_tag": "v1.0.0"
-            ... }, workflow_name="cloud")
+            ... }, strategy_name="cloud")
         """
-        if workflow_name is None:
-            workflow_name = self.launch_type
-        self._manager.update_workflow_config(workflow_name, config)
-        logger.debug(f"Updated workflow config for '{workflow_name}'")
+        if strategy_name is None:
+            strategy_name = self.launch_type
+        self._manager.update_strategy_config(strategy_name, config)
+        logger.debug(f"Updated strategy config for '{strategy_name}'")
         return self
-    
+
     # ========== Utility Methods ==========
-    
+
     def __repr__(self) -> str:
         """String representation for debugging."""
         return (
@@ -574,7 +629,7 @@ class AgentConfig:
             f"agent={self.agent_name}, "
             f"launch_type={self.launch_type})"
         )
-    
+
     def __str__(self) -> str:
         """Human-readable string representation."""
         return (
